@@ -158,9 +158,13 @@ class webhandler:
         if os.path.isfile((image_path := os.path.join(path, image_type))) and not force:
             return image_path
         else:
-            return self.download(
-                self.domain + f"packages/{name}/{image_type}", image_path
-            )
+            try:
+                return self.download(
+                    self.domain + f"packages/{name}/{image_type}", image_path
+                )
+            except Exception as e:
+                print(f"Failed to download {image_type} for {name} - {e}")
+                return None
 
     def get_icon(self, name: str, force: bool = False) -> str:
         """
